summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_html_notes.py
diff options
context:
space:
mode:
authorMattia Rizzolo <mattia@mapreri.org>2015-03-01 19:16:58 +0100
committerHolger Levsen <holger@layer-acht.org>2015-03-01 20:12:52 +0100
commitb9ade4de2f93cf95ed950e45f420f04d0b672341 (patch)
tree213b03d4015e31d1c491eaa4413d486b07907d6b /bin/reproducible_html_notes.py
parent531197f7d52651c6387ca2eb78434bcb6c1891c6 (diff)
downloadjenkins.debian.net-b9ade4de2f93cf95ed950e45f420f04d0b672341.tar.xz
reproducible: notes: fix multiarch url in gen_html_issue()
Diffstat (limited to 'bin/reproducible_html_notes.py')
-rwxr-xr-xbin/reproducible_html_notes.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/bin/reproducible_html_notes.py b/bin/reproducible_html_notes.py
index bf58425b..836b6ccf 100755
--- a/bin/reproducible_html_notes.py
+++ b/bin/reproducible_html_notes.py
@@ -242,9 +242,9 @@ def gen_html_issue(issue):
try:
affected += tab*4 + '<b>' + str(len(issues_count[issue])) + '</b>:\n'
for pkg in sorted(issues_count[issue]):
- # FIXME we currently consider notes only for sid
- affected += tab*7 + '<a href="%s/sid/%s.html" class="noted">%s</a>\n' \
- % (RB_PKG_URI, pkg, pkg)
+ # FIXME we currently consider notes only for sid/amd64
+ affected += tab*7 + '<a href="%s/sid/amd64/%s.html" ' + \
+ 'class="noted">%s</a>\n' % (RB_PKG_URI, pkg, pkg)
except KeyError: # The note is not listed in any package, that is
affected = '<i>None</i>'
# check for description: